@@ -2,15 +2,32 @@
 # run-uninstalls.pl
 # Run all the uninstall.pl scripts in module directories
 
+use lib '.';
+BEGIN { push(@INC, "."); };
 $no_acl_check++;
 use WebminCore;
 &init_config();
+@themes = &list_themes();
 
 if (@ARGV > 0) {
-	@mods = map { local %minfo = &get_module_info($_); \%minfo } @ARGV;
+	# Running for specified modules
+	foreach $a (@ARGV) {
+		local %minfo = &get_module_info($a);
+		if (!%minfo) {
+			# Try for a theme
+			($tinfo) = grep { $_->{'dir'} eq $a } @themes;
+			if ($tinfo) {
+				push(@mods, $tinfo);
+				}
+			}
+		else {
+			push(@mods, \%minfo);
+			}
+		}
 	}
 else {
-	@mods = &get_all_module_infos();
+	# Running on all modules and themes
+	@mods = ( &get_all_module_infos(), @themes );
 	}
 
 foreach $m (@mods) {
@@ -24,7 +41,7 @@ foreach $m (@mods) {
 			&foreign_call($m->{'dir'}, "module_uninstall");
 			};
 		if ($@) {
-			print STDERR "$m->{'dir'}/postinstall.pl failed : $@\n";
+			print STDERR "$m->{'dir'}/uninstall.pl failed : $@\n";
 			}
 		}
 	}
